You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by pf...@apache.org on 2014/04/29 21:05:21 UTC

svn commit: r1591058 [9/15] - in /openoffice/trunk/main: ./ accessibility/bridge/org/openoffice/java/accessibility/ accessibility/bridge/source/java/ accessibility/inc/accessibility/extended/ accessibility/inc/accessibility/standard/ accessibility/sour...

Modified: openoffice/trunk/main/filter/source/msfilter/msocximex.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/msfilter/msocximex.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/msfilter/msvbahelper.cxx (original)
+++ openoffice/trunk/main/filter/source/msfilter/msvbahelper.cxx Tue Apr 29 19:05:05 2014
@@ -423,7 +423,7 @@ MacroResolvedInfo resolveVBAMacro( SfxOb
     return aRes;
 }
 
-// Treat the args as possible inouts ( convertion at bottom of method )
+// Treat the args as possible inouts ( conversion at bottom of method )
 sal_Bool executeMacro( SfxObjectShell* pShell, const String& sMacroName, uno::Sequence< uno::Any >& aArgs, uno::Any& aRet, const uno::Any& /*aCaller*/)
 {
     sal_Bool bRes = sal_False;

Modified: openoffice/trunk/main/filter/source/msfilter/svxmsbas.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/msfilter/svxmsbas.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/msfilter/svxmsbas.cxx (original)
+++ openoffice/trunk/main/filter/source/msfilter/svxmsbas.cxx Tue Apr 29 19:05:05 2014
@@ -313,7 +313,7 @@ sal_Bool SvxImportMSVBasic::ImportCode_I
                 const String &sBasicModule = aVBA.GetStreamName( i);
 #endif
                 /* #117718# expose information regarding type of Module
-                * Class, Form or plain 'ould VBA module with a REM statment
+                * Class, Form or plain 'ould VBA module with a REM statement
                 * at the top of the module. Mapping of Module Name
                 * to type is performed in  VBA_Impl::Open() method,
                 * ( msvbasic.cxx ) by examining the PROJECT stream.

Modified: openoffice/trunk/main/filter/source/xmlfilterdetect/filterdetect.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xmlfilterdetect/filterdetect.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xmlfilterdetect/filterdetect.cxx (original)
+++ openoffice/trunk/main/filter/source/xmlfilterdetect/filterdetect.cxx Tue Apr 29 19:05:05 2014
@@ -186,7 +186,7 @@ Reference< com::sun::star::frame::XModel
         }
         catch(Exception &)
         {
-                 OSL_ENSURE( sal_False, "An Exception occured while opening File stream" );
+                 OSL_ENSURE( sal_False, "An Exception occurred while opening File stream" );
         }
         if(sTypeName.equalsAscii(""))
         {

Modified: openoffice/trunk/main/filter/source/xslt/common/math.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/common/math.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/common/math.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/common/math.xsl Tue Apr 29 19:05:05 2014
@@ -35,7 +35,7 @@ Public Functions
     abs(x)
     max(x1,x2)
     min(x1,x2)
-    power(x,power(interger only), rounding-factor=100)
+    power(x,power(integer only), rounding-factor=100)
     sqrt(x, rounding-factor=100)
     convert2radian(x,rounding-factor=100)
     convert2degree(x,rounding-factor=100)

Modified: openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/ooo2spreadsheetml.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/ooo2spreadsheetml.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/ooo2spreadsheetml.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/ooo2spreadsheetml.xsl Tue Apr 29 19:05:05 2014
@@ -83,7 +83,7 @@
 	<xsl:param name="targetBaseURL" select="'./'" />
 
 	<!-- OPTIONAL: (MANDATORY: for input document with relative internal links)
-		 To access contents of a office file (content like the meta.xml, styles.xml file or  graphics) a URL could be choosen.
+		 To access contents of a office file (content like the meta.xml, styles.xml file or  graphics) a URL could be chosen.
 	 This could be even a JAR URL. The sourceBase of the content URL "jar:file:/C:/temp/Test.sxw!/content.xml" would be
 	 "jar:file:/C:/temp/Test.sxw!/" for example.
 		 When working with OpenOffice API a Package-URL encoded over HTTP can be used to access the jared contents of the the jared document. -->

Modified: openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/table.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/table.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/table.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/export/spreadsheetml/table.xsl Tue Apr 29 19:05:05 2014
@@ -471,7 +471,7 @@
 		<xsl:param name="calculatedCellPosition" select="1" /><!-- the later table position of the current cell  -->
 		<xsl:param name="calculatedRowPosition" /><!-- the later table position of the current row  -->
 		<xsl:param name="setIndex" select="false()" /> <!-- if not '0' @ss:Index used for neglecting repeteated empty cells -->
-		<xsl:param name="repetition" select="@table:number-columns-repeated" /> <!-- used for explicit writen out cells -->
+		<xsl:param name="repetition" select="@table:number-columns-repeated" /> <!-- used for explicit written out cells -->
 		<xsl:param name="repetitionCellPosition" select="$calculatedCellPosition" /><!-- during repetition formula needs exact cell positioning -->
 		<xsl:param name="nextMatchedCellPosition"><!-- the later table position of the next cell  -->
 		<xsl:choose>

Modified: openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_draw.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_draw.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_draw.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_draw.xsl Tue Apr 29 19:05:05 2014
@@ -49,7 +49,7 @@
 		</xsl:variable>
 		<xsl:choose>
 			<!--
-						  deal with captions and frames first. draw:text-box is a powerfull element in OOo, its GUI name is frame. And OOo use it to contain Captions
+						  deal with captions and frames first. draw:text-box is a powerful element in OOo, its GUI name is frame. And OOo use it to contain Captions
 						  Since there is not a corresponding object in word, so we draw the text-box itself and its children separately. If it look like a Caption only frame
 						  we'll adjust the text-box position to make it look pretty
 			 -->

Modified: openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_field.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_field.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_field.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/export/wordml/ooo2wordml_field.xsl Tue Apr 29 19:05:05 2014
@@ -359,7 +359,7 @@ $field_number_format_style ='壹, è�
         </w:fldSimple>
     </xsl:template>
     <xsl:template name="field_convert_linebreak">
-        <!-- this template convert the linebreak (&#x0A; and &#x0D;) in continous text to Ms word element<w:br/> -->
+        <!-- this template convert the linebreak (&#x0A; and &#x0D;) in continuous text to Ms word element<w:br/> -->
         <xsl:param name="field_input_text"/>
         <xsl:if test="not (contains($field_input_text,'&#x0A;'))">
             <w:t>

Modified: openoffice/trunk/main/filter/source/xslt/import/spreadsheetml/spreadsheetml2ooo.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/import/spreadsheetml/spreadsheetml2ooo.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/import/spreadsheetml/spreadsheetml2ooo.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/import/spreadsheetml/spreadsheetml2ooo.xsl Tue Apr 29 19:05:05 2014
@@ -4274,7 +4274,7 @@
 							<xsl:when test="ss:Alignment/@ss:Vertical = 'Center'">middle</xsl:when>
 							<xsl:when test="ss:Alignment/@ss:Vertical = 'Bottom'">bottom</xsl:when>
 							<xsl:when test="ss:Alignment/@ss:Vertical = 'Automatic'">middle</xsl:when>
-							<!-- actually for vertical writen characters, not supported by StarOffice/OpenOffice now yet -->
+							<!-- actually for vertical written characters, not supported by StarOffice/OpenOffice now yet -->
 							<xsl:otherwise>middle</xsl:otherwise>
 						</xsl:choose>
 					</xsl:variable>

Modified: openoffice/trunk/main/filter/source/xslt/import/uof2/uof2odf.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/import/uof2/uof2odf.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/import/uof2/uof2odf.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/import/uof2/uof2odf.xsl Tue Apr 29 19:05:05 2014
@@ -2162,10 +2162,10 @@
 		</xsl:for-each>
 	</xsl:template>
 	<xsl:template match="字:上下标类型_4143" mode="sentence">
-		<xsl:variable name="positon">
+		<xsl:variable name="position">
 			<xsl:value-of select="."/>
 		</xsl:variable>
-		<xsl:attribute name="style:text-position"><xsl:choose><xsl:when test="contains($positon,'sup')">super 58%</xsl:when><xsl:when test="contains($positon,'sub')">sub 58%</xsl:when></xsl:choose></xsl:attribute>
+		<xsl:attribute name="style:text-position"><xsl:choose><xsl:when test="contains($position,'sup')">super 58%</xsl:when><xsl:when test="contains($position,'sub')">sub 58%</xsl:when></xsl:choose></xsl:attribute>
 	</xsl:template>
 	<xsl:template match="字:缩放_4144" mode="sentence">
 		<xsl:attribute name="style:text-scale"><xsl:value-of select="."/>%</xsl:attribute>
@@ -13233,7 +13233,7 @@ iVBORw0KGgoAAAANSUhEUgAAAAgAAAAICAIAAABL
 				</xsl:when>
 			</xsl:choose>
 			<xsl:attribute name="draw:opacity">100%</xsl:attribute>
-			<!-- no Foreward Color data in ODF -->
+			<!-- no Forward Color data in ODF -->
 			<xsl:if test="图表:数据标记_E70E/@背景色E711">
 				<xsl:attribute name="draw:stroke" select="'solid'"/>
 				<xsl:attribute name="svg:stroke-color" select="图表:数据标记_E70E/@背景色E711"/>

Modified: openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo.xsl Tue Apr 29 19:05:05 2014
@@ -233,7 +233,7 @@
     <xsl:template match="w:body">
         <xsl:element name="office:body">
             <xsl:element name="office:text">
-                <!-- to add the sequece variable declaration at the begining of the office:body  G.Y.-->
+                <!-- to add the sequece variable declaration at the beginning of the office:body  G.Y.-->
                 <text:sequence-decls>
                     <xsl:call-template name="default_seqence_declaration"/>
                     <xsl:apply-templates select="/w:wordDocument/w:body//w:instrText[substring(normalize-space(text()),1,3) = 'SEQ' ] | /w:wordDocument/w:body//w:fldSimple[substring(normalize-space(@w:instr),1,3) = 'SEQ' ]  " mode="sequence_declare"/>

Modified: openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_draw.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_draw.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_draw.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_draw.xsl Tue Apr 29 19:05:05 2014
@@ -1720,7 +1720,7 @@
                 <xsl:number from="/w:wordDocument/w:body" level="any" count="v:textpath" format="1"/>
             </xsl:variable>
             <xsl:variable name="font-family">
-                <!--  we need remove the addtional  &quot; from font-family -->
+                <!--  we need remove the additional  &quot; from font-family -->
                 <xsl:value-of select="translate(substring-before(substring-after(@style,'font-family:'),';'), '&quot;' ,'')"/>
             </xsl:variable>
             <xsl:variable name="font-size">

Modified: openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_path.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_path.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_path.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/import/wordml/wordml2ooo_path.xsl Tue Apr 29 19:05:05 2014
@@ -1529,7 +1529,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'n' ">
@@ -1546,7 +1546,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'w' ">
@@ -1563,7 +1563,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'q' ">
@@ -1581,7 +1581,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="$curr-char = 'h' ">
@@ -1597,7 +1597,7 @@
                             <xsl:value-of select="concat( $curr-char,$second-char , ':'  , $position +2)"/>
                         </xsl:if>
                         <xsl:if test="$isvalid = '0' ">
-                            <xsl:message>ooo2wordml_path.xsl: Error command occured </xsl:message>
+                            <xsl:message>ooo2wordml_path.xsl: Error command occurred </xsl:message>
                         </xsl:if>
                     </xsl:when>
                     <xsl:when test="string-length(translate($curr-char ,  'mlcxetrv' ,'')) = 0 ">

Modified: openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_cells.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_cells.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_cells.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_cells.xsl Tue Apr 29 19:05:05 2014
@@ -64,7 +64,7 @@
 	<!-- matching cells to give out -> covered table cells are not written out -->
 	<xsl:template match="table:table-cell">
 		<xsl:param name="globalData" />
-		<!-- position of the current input cell to get the correct colum style (hidden are also counted)-->
+		<!-- position of the current input cell to get the correct column style (hidden are also counted)-->
 		<xsl:param name="allTableColumns" />
 		<xsl:param name="maxRowLength" />
 		<xsl:param name="tableDataType" />
@@ -101,7 +101,7 @@
 		<xsl:choose>
 			<xsl:when test="function-available('common:node-set')">
 				<xsl:call-template name="create-table-cell">
-					<!-- position of the current input cell to get the correct colum style (hidden are also counted)-->
+					<!-- position of the current input cell to get the correct column style (hidden are also counted)-->
 					<xsl:with-param name="allTableColumns"  select="$allTableColumns" />
 					<xsl:with-param name="maxRowLength"     select="$maxRowLength" />
 					<xsl:with-param name="precedingColumns"   select="sum(common:node-set($precedingCells)/*)" />
@@ -111,7 +111,7 @@
 			</xsl:when>
 			<xsl:when test="function-available('xalan:nodeset')">
 				<xsl:call-template name="create-table-cell">
-					<!-- position of the current input cell to get the correct colum style (hidden are also counted)-->
+					<!-- position of the current input cell to get the correct column style (hidden are also counted)-->
 					<xsl:with-param name="allTableColumns"  select="$allTableColumns" />
 					<xsl:with-param name="maxRowLength"     select="$maxRowLength" />
 					<xsl:with-param name="precedingColumns"   select="sum(xalan:nodeset($precedingCells)/*)" />
@@ -121,7 +121,7 @@
 			</xsl:when>
 			<xsl:when test="function-available('xt:node-set')">
 				<xsl:call-template name="create-table-cell">
-					<!-- position of the current input cell to get the correct colum style (hidden are also counted)-->
+					<!-- position of the current input cell to get the correct column style (hidden are also counted)-->
 					<xsl:with-param name="allTableColumns"  select="$allTableColumns" />
 					<xsl:with-param name="maxRowLength"     select="$maxRowLength" />
 					<xsl:with-param name="precedingColumns"   select="sum(xt:node-set($precedingCells)/*)" />
@@ -138,7 +138,7 @@
 
 	<!-- current node is a table:table-cell -->
 	<xsl:template name="create-table-cell">
-		<!-- position of the current input cell to get the correct colum style (hidden are also counted)-->
+		<!-- position of the current input cell to get the correct column style (hidden are also counted)-->
 		<xsl:param name="allTableColumns" />
 		<xsl:param name="globalData" />
 		<xsl:param name="maxRowLength" />

Modified: openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_rows.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_rows.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_rows.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table/table_rows.xsl Tue Apr 29 19:05:05 2014
@@ -66,7 +66,7 @@
 		<xsl:param name="allTableColumns" />
 
 		<!-- Some Office Calc documents simulate a background by repeating one of the later cells until end of used space
-			 (The value of "table:number-columns-repeated" is enourmous). Writing out all these cells would be fatal in time
+			 (The value of "table:number-columns-repeated" is enormous). Writing out all these cells would be fatal in time
 			 and output size. Therefore, this global variable shows us the longest row with content. -->
 		<xsl:variable name="maxRowLength" select="count($allTableColumns/table:table-column)" />
 		<xsl:if test="$debugEnabled">

Modified: openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table_of_content.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table_of_content.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table_of_content.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/common/table_of_content.xsl Tue Apr 29 19:05:05 2014
@@ -452,7 +452,7 @@ Scenarios unmatched:
 		</xsl:choose>
 	</xsl:template>
 
-	<!-- As the span width will be mapped to column width, the preceding span widths have to be substracted -->
+	<!-- As the span width will be mapped to column width, the preceding span widths have to be subtracted -->
 	<xsl:template name="create-cell-width">
 		<xsl:param name="width"/>
 		<xsl:param name="unit"/>

Modified: openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/body.xsl Tue Apr 29 19:05:05 2014
@@ -797,7 +797,7 @@
 					<xsl:when test="$createDiv and normalize-space(.) != ''">
 						<!-- every following frame sibling till the next draw:frame
 							have to be incapuslated within a div with left indent.
-							To be moved alltogether arcording the indent (usually right) -->
+							To be moved altogether arcording the indent (usually right) -->
 						<xsl:comment>Next 'div' added for floating.</xsl:comment>
 						<xsl:element name="div">
 							<xsl:attribute name="style">
@@ -881,7 +881,7 @@
 
 
 
-	<!-- As draw:fame may occure within more elements than in text:p and draw:page -->
+	<!-- As draw:fame may occur within more elements than in text:p and draw:page -->
 	<xsl:template match="draw:frame">
 		<xsl:param name="globalData"/>
 		<xsl:param name="previousFrameWidths" select="0"/>
@@ -990,7 +990,7 @@
 		<xsl:if test="@text:anchor-type='paragraph'">
 			<xsl:comment>Next 'div' is emulating the top hight of a draw:frame.</xsl:comment>
 			<!-- When the svg:y is set relativ to the paragraph content, the best way to emulate a positive height,
-			 is to add an invisbile division inbetween with a height.
+			 is to add an invisbile division between with a height.
 			 Often text will flow into this 'gap', which is handled separately!
 			 -->
 			<xsl:if test="$svgY &gt; 0">
@@ -1551,7 +1551,7 @@
 
 		B)
 		Since OASIS Open Document XML (implemented in OOo2.0) only one parent type exists for list items
-		the 'text:list' element. The XHTML element 'ol', 'ul' will be choosen upon the list style type.
+		the 'text:list' element. The XHTML element 'ol', 'ul' will be chosen upon the list style type.
 
 		C)
 		An Office list may be spread over the whole document. Linked by their style and text:continue-numbering='true'.

Modified: openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/opendoc2xhtml.xsl
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/opendoc2xhtml.xsl?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/opendoc2xhtml.xsl (original)
+++ openoffice/trunk/main/filter/source/xslt/odf2xhtml/export/xhtml/opendoc2xhtml.xsl Tue Apr 29 19:05:05 2014
@@ -95,7 +95,7 @@
 	<xsl:param name="targetURL" select="'./'" />
 
 	<!-- OPTIONAL: (MANDATORY: for input document with relative internal links)
-		 To access contents of a office file (content like the meta.xml, styles.xml file or  graphics) a URL could be choosen.
+		 To access contents of a office file (content like the meta.xml, styles.xml file or  graphics) a URL could be chosen.
 	 This could be even a JAR URL. The sourceBase of the content URL "jar:file:/C:/temp/Test.sxw!/content.xml" would be
 	 "jar:file:/C:/temp/Test.sxw!/" for example.
 		 When working with OpenOffice API a Package-URL encoded over HTTP can be used to access the jared contents of the the jared document. -->

Modified: openoffice/trunk/main/filter/source/xsltdialog/xmlfiltertestdialog.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xsltdialog/xmlfiltertestdialog.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xsltdialog/xmlfiltertestdialog.cxx (original)
+++ openoffice/trunk/main/filter/source/xsltdialog/xmlfiltertestdialog.cxx Tue Apr 29 19:05:05 2014
@@ -378,7 +378,7 @@ void XMLFilterTestDialog::onExportBrowse
 
 				if( (nFound == 15) && (aType.getLength() && aService == mpFilterInfo->maDocumentService) )
 				{
-					// see if this filter is not supressed in dialog
+					// see if this filter is not suppressed in dialog
 					if( (nFlags & 0x1000) == 0 )
 					{
 						aAny = xTypeDetection->getByName( aType );

Modified: openoffice/trunk/main/filter/source/xsltfilter/com/sun/star/comp/xsltfilter/Base64.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/xsltfilter/com/sun/star/comp/xsltfilter/Base64.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/filter/source/xsltfilter/com/sun/star/comp/xsltfilter/Base64.java (original)
+++ openoffice/trunk/main/filter/source/xsltfilter/com/sun/star/comp/xsltfilter/Base64.java Tue Apr 29 19:05:05 2014
@@ -473,7 +473,7 @@ public class Base64
      * anywhere along their length by specifying 
      * <var>srcOffset</var> and <var>destOffset</var>.
      * This method does not check to make sure your arrays
-     * are large enough to accomodate <var>srcOffset</var> + 3 for
+     * are large enough to accommodate <var>srcOffset</var> + 3 for
      * the <var>source</var> array or <var>destOffset</var> + 4 for
      * the <var>destination</var> array.
      * The actual number of significant bytes in your array is
@@ -826,7 +826,7 @@ public class Base64
      * anywhere along their length by specifying 
      * <var>srcOffset</var> and <var>destOffset</var>.
      * This method does not check to make sure your arrays
-     * are large enough to accomodate <var>srcOffset</var> + 4 for
+     * are large enough to accommodate <var>srcOffset</var> + 4 for
      * the <var>source</var> array or <var>destOffset</var> + 3 for
      * the <var>destination</var> array.
      * This method returns the actual number of bytes that 

Modified: openoffice/trunk/main/forms/qa/complex/forms/CheckOGroupBoxModel.java
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/qa/complex/forms/CheckOGroupBoxModel.java?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/qa/complex/forms/CheckOGroupBoxModel.java (original)
+++ openoffice/trunk/main/forms/qa/complex/forms/CheckOGroupBoxModel.java Tue Apr 29 19:05:05 2014
@@ -117,15 +117,15 @@ public class CheckOGroupBoxModel
         }
         catch (com.sun.star.beans.PropertyVetoException e)
         {
-            fail("Exception occured while trying to change the properties.");
+            fail("Exception occurred while trying to change the properties.");
         }
         catch (com.sun.star.lang.IllegalArgumentException e)
         {
-            fail("Exception occured while trying to change the properties.");
+            fail("Exception occurred while trying to change the properties.");
         }
         catch (com.sun.star.lang.WrappedTargetException e)
         {
-            fail("Exception occured while trying to change the properties.");
+            fail("Exception occurred while trying to change the properties.");
         } // end of try-catch
 
         assertTrue("Listener was not called.", ml.wasListenerCalled());

Modified: openoffice/trunk/main/forms/source/component/Columns.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/component/Columns.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/component/Columns.cxx (original)
+++ openoffice/trunk/main/forms/source/component/Columns.cxx Tue Apr 29 19:05:05 2014
@@ -194,7 +194,7 @@ Sequence<Type> SAL_CALL OGridColumn::get
 Any SAL_CALL OGridColumn::queryAggregation( const Type& _rType ) throw (RuntimeException)
 {
     Any aReturn;
-    // some functionality at our aggregate cannot be reasonably fullfilled here.
+    // some functionality at our aggregate cannot be reasonably fulfilled here.
     if  (   _rType.equals(::getCppuType(static_cast< Reference< XFormComponent >* >(NULL)))
         ||  _rType.equals(::getCppuType(static_cast< Reference< XServiceInfo >* >(NULL)))
         ||  _rType.equals(::getCppuType(static_cast< Reference< XBindableValue >* >(NULL)))

Modified: openoffice/trunk/main/forms/source/component/DatabaseForm.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/component/DatabaseForm.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/component/DatabaseForm.cxx (original)
+++ openoffice/trunk/main/forms/source/component/DatabaseForm.cxx Tue Apr 29 19:05:05 2014
@@ -90,7 +90,7 @@
 #include <ctype.h>
 #include <hash_map>
 
-// compatiblity: DatabaseCursorType is dead, but for compatiblity reasons we still have to write it ...
+// compatibility: DatabaseCursorType is dead, but for compatibility reasons we still have to write it ...
 namespace com {
 namespace sun {
 namespace star {
@@ -3099,7 +3099,7 @@ void SAL_CALL ODatabaseForm::rowSetChang
 	// if our parent is an ODatabaseForm, too, then after this rowSetChanged we'll get a "reloaded"
 	// or a "loaded" event.
 	// If somebody gave us another parent which is an XRowSet but doesn't handle an execute as
-	// "load" respectivly "reload" ... can't do anything ....
+	// "load" respectively "reload" ... can't do anything ....
 }
 
 //------------------------------------------------------------------------------

Modified: openoffice/trunk/main/forms/source/component/FormComponent.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/component/FormComponent.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/component/FormComponent.cxx (original)
+++ openoffice/trunk/main/forms/source/component/FormComponent.cxx Tue Apr 29 19:05:05 2014
@@ -1330,7 +1330,7 @@ OBoundControlModel::OBoundControlModel(
     m_aValuePropertyType = _pOriginal->m_aValuePropertyType;
 	m_aControlSource = _pOriginal->m_aControlSource;
 	m_bInputRequired = _pOriginal->m_bInputRequired;
-	// m_xLabelControl, though being a property, is not to be cloned, not even the reference will be transfered.
+	// m_xLabelControl, though being a property, is not to be cloned, not even the reference will be transferred.
 	// (the former should be clear - a clone of the object we're only referencing does not make sense)
 	// (the second would violate the restriction for label controls that they're part of the
 	// same form component hierarchy - we ourself are no part, yet, so we can't have a label control)
@@ -1967,7 +1967,7 @@ void SAL_CALL OBoundControlModel::proper
 	// if the DBColumn value changed, transfer it to the control
 	if ( evt.PropertyName.equals( PROPERTY_VALUE ) )
 	{
-        OSL_ENSURE( evt.Source == getField(), "OBoundControlModel::propertyChange: value changes from components other than our database colum?" );
+        OSL_ENSURE( evt.Source == getField(), "OBoundControlModel::propertyChange: value changes from components other than our database column?" );
 		osl::MutexGuard aGuard(m_aMutex);
 		if ( m_bForwardValueChanges && m_xColumn.is() )
 			transferDbValueToControl();
@@ -2246,7 +2246,7 @@ void OBoundControlModel::impl_connectDat
     }
 
     // now that we're connected (more or less, even if we did not find a column),
-    // we definately want to forward any potentially occuring value changes
+    // we definitely want to forward any potentially occurring value changes
     m_bForwardValueChanges = sal_True;
 
     // let derived classes react on this new connection

Modified: openoffice/trunk/main/forms/source/component/ListBox.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/component/ListBox.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/component/ListBox.cxx (original)
+++ openoffice/trunk/main/forms/source/component/ListBox.cxx Tue Apr 29 19:05:05 2014
@@ -1257,7 +1257,7 @@ namespace frm
         {
             Any aReturn;
 
-            // by definition, multiple selected entries are transfered as NULL if the
+            // by definition, multiple selected entries are transferred as NULL if the
             // binding does not support string lists
             if ( _rSelectSequence.getLength() <= 1 )
             {

Modified: openoffice/trunk/main/forms/source/component/RadioButton.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/component/RadioButton.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/component/RadioButton.hxx (original)
+++ openoffice/trunk/main/forms/source/component/RadioButton.hxx Tue Apr 29 19:05:05 2014
@@ -77,7 +77,7 @@ protected:
 private:
     /** sets the given value as new State at the aggregate
         @precond
-            our mutex is aquired exactly once
+            our mutex is acquired exactly once
     */
     void    setNewAggregateState( const ::com::sun::star::uno::Any& _rValue );
 };

Modified: openoffice/trunk/main/forms/source/component/clickableimage.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/component/clickableimage.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/component/clickableimage.cxx (original)
+++ openoffice/trunk/main/forms/source/component/clickableimage.cxx Tue Apr 29 19:05:05 2014
@@ -600,7 +600,7 @@ namespace frm
     Any SAL_CALL OClickableImageBaseModel::queryAggregation(const Type& _rType) throw (RuntimeException)
     {
         // order matters:
-        // we definately want to "overload" the XImageProducer interface of our aggregate,
+        // we definitely want to "overload" the XImageProducer interface of our aggregate,
         // thus check OClickableImageBaseModel_Base (which provides this) first
         Any aReturn = OClickableImageBaseModel_Base::queryInterface( _rType );
 

Modified: openoffice/trunk/main/forms/source/component/propertybaghelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/component/propertybaghelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/component/propertybaghelper.cxx (original)
+++ openoffice/trunk/main/forms/source/component/propertybaghelper.cxx Tue Apr 29 19:05:05 2014
@@ -131,7 +131,7 @@ namespace frm
         if ( ( nHandle != -1 ) && rPropInfo.fillPropertyMembersByHandle( NULL, NULL, nHandle ) )
             nHandle = -1;
 
-        // seach a free handle in <math>F_1009</math>
+        // search a free handle in <math>F_1009</math>
         if ( nHandle == -1 )
         {
             sal_Int32 nPrime = 1009;

Modified: openoffice/trunk/main/forms/source/inc/FormComponent.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/inc/FormComponent.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/inc/FormComponent.hxx (original)
+++ openoffice/trunk/main/forms/source/inc/FormComponent.hxx Tue Apr 29 19:05:05 2014
@@ -194,7 +194,7 @@ public:
             the aggregate. In this case, you <em>have</em> to call doSetDelegator within your
             own constructor.
 
-            This is helpfull, if your derived class wants to cache an interface of the aggregate.
+            This is helpful, if your derived class wants to cache an interface of the aggregate.
             In this case, the aggregate needs to be queried for this interface <b>before</b> the
             <member scope="com::sun::star::uno">XAggregation::setDelegator</member> call.
 
@@ -674,7 +674,7 @@ private:
     const sal_Bool              m_bSupportsExternalBinding  : 1;    // do we support XBindableValue?
     const sal_Bool			    m_bSupportsValidation       : 1;    // do we support XValidatable?
 	sal_Bool					m_bForwardValueChanges      : 1;    // do we currently handle changes in the bound database field?
-    sal_Bool			        m_bTransferingValue         : 1;    // true if we're currently transfering our value to an external binding
+    sal_Bool			        m_bTransferingValue         : 1;    // true if we're currently transferring our value to an external binding
     sal_Bool                    m_bIsCurrentValueValid      : 1;    // flag specifying whether our current value is valid, relative to our external validator
     sal_Bool                    m_bBindingControlsRO        : 1;    // is our ReadOnly property currently controlled by our external binding?
     sal_Bool                    m_bBindingControlsEnable    : 1;    // is our Enabled property currently controlled by our external binding?

Modified: openoffice/trunk/main/forms/source/richtext/richtextcontrol.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/richtext/richtextcontrol.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/richtext/richtextcontrol.cxx (original)
+++ openoffice/trunk/main/forms/source/richtext/richtextcontrol.cxx Tue Apr 29 19:05:05 2014
@@ -243,7 +243,7 @@ namespace frm
             DBG_ASSERT( pPeer, "ORichTextControl::createPeer: invalid peer returned!" );
             if ( pPeer )
             {
-                // by definition, the returned component is aquired once
+                // by definition, the returned component is acquired once
                 pPeer->release();
 
                 // announce the peer to the base class
@@ -344,7 +344,7 @@ namespace frm
 
         // the peer itself
         ORichTextPeer* pPeer = new ORichTextPeer;
-        pPeer->acquire();   // by definition, the returned object is aquired once
+        pPeer->acquire();   // by definition, the returned object is acquired once
 
         // the VCL control for the peer
         RichTextControl* pRichTextControl = new RichTextControl( pEngine, _pParentWindow, _nStyle, NULL, pPeer );

Modified: openoffice/trunk/main/forms/source/richtext/richtextcontrol.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/richtext/richtextcontrol.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/richtext/richtextcontrol.hxx (original)
+++ openoffice/trunk/main/forms/source/richtext/richtextcontrol.hxx Tue Apr 29 19:05:05 2014
@@ -109,7 +109,7 @@ namespace frm
     public:
         /** factory method
             @return
-                a new ORichTextPeer instance, which has been aquired once!
+                a new ORichTextPeer instance, which has been acquired once!
         */
         static ORichTextPeer* Create(
             const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XControlModel >&         _rxModel,

Modified: openoffice/trunk/main/forms/source/richtext/richtextimplcontrol.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/richtext/richtextimplcontrol.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/solar/component/navbarcontrol.cxx (original)
+++ openoffice/trunk/main/forms/source/solar/component/navbarcontrol.cxx Tue Apr 29 19:05:05 2014
@@ -180,7 +180,7 @@ namespace frm
             ONavigationBarPeer* pPeer = ONavigationBarPeer::Create( maContext.getLegacyServiceFactory(), pParentWin, getModel() );
             DBG_ASSERT( pPeer, "ONavigationBarControl::createPeer: invalid peer returned!" );
             if ( pPeer )
-                // by definition, the returned component is aquired once
+                // by definition, the returned component is acquired once
                 pPeer->release();
 
             // announce the peer to the base class
@@ -275,7 +275,7 @@ namespace frm
 
         // the peer itself
         ONavigationBarPeer* pPeer = new ONavigationBarPeer( _rxORB );
-        pPeer->acquire();   // by definition, the returned object is aquired once
+        pPeer->acquire();   // by definition, the returned object is acquired once
 
         // the VCL control for the peer
         Reference< XModel > xContextDocument( getXModel( _rxModel ) );

Modified: openoffice/trunk/main/forms/source/solar/component/navbarcontrol.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/solar/component/navbarcontrol.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/solar/component/navbarcontrol.hxx (original)
+++ openoffice/trunk/main/forms/source/solar/component/navbarcontrol.hxx Tue Apr 29 19:05:05 2014
@@ -99,7 +99,7 @@ namespace frm
     public:
         /** factory method
             @return
-                a new ONavigationBarPeer instance, which has been aquired once!
+                a new ONavigationBarPeer instance, which has been acquired once!
         */
         static ONavigationBarPeer* Create(
             const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XMultiServiceFactory >& _rxORB,

Modified: openoffice/trunk/main/forms/source/solar/inc/navtoolbar.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/solar/inc/navtoolbar.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/solar/inc/navtoolbar.hxx (original)
+++ openoffice/trunk/main/forms/source/solar/inc/navtoolbar.hxx Tue Apr 29 19:05:05 2014
@@ -85,7 +85,7 @@ namespace frm
             then the states of the features are updated
 
             @param _pDispatcher
-                the new (or old) dispatcher. The caller is reponsible for
+                the new (or old) dispatcher. The caller is responsible for
                 ensuring the life time of the object does exceed the life time
                 of the tool bar instance.
         */

Modified: openoffice/trunk/main/forms/source/xforms/binding.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/xforms/binding.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/xforms/binding.cxx (original)
+++ openoffice/trunk/main/forms/source/xforms/binding.cxx Tue Apr 29 19:05:05 2014
@@ -674,7 +674,7 @@ void Binding::bind( bool bForceRebind )
             }
         }
 
-        // now evaluate remaining MIPs in the apropriate context
+        // now evaluate remaining MIPs in the appropriate context
         maReadonly.evaluate( rContext );
         maRelevant.evaluate( rContext );
         maRequired.evaluate( rContext );
@@ -1274,7 +1274,7 @@ void Binding::handleEvent( const XEvent_
 
 		// the modification of the 'mnDeferModifyNotifications'-member
 		// is necessary to prevent infinite notication looping.
-		// This can happend in case the binding which caused
+		// This can happened in case the binding which caused
 		// the notification chain is listening to those events
 		// as well...
         bool bPreserveValueModified = mbValueModified;

Modified: openoffice/trunk/main/forms/source/xforms/convert.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/xforms/convert.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/xforms/convert.hxx (original)
+++ openoffice/trunk/main/forms/source/xforms/convert.hxx Tue Apr 29 19:05:05 2014
@@ -94,7 +94,7 @@ public:
             sal_Int16   _nWhitespaceTreatment
     );
 
-    /** replace all occurences 0x08, 0x0A, 0x0D with 0x20
+    /** replace all occurrences 0x08, 0x0A, 0x0D with 0x20
     */
     static ::rtl::OUString replaceWhitespace( const ::rtl::OUString& _rString );
 

Modified: openoffice/trunk/main/forms/source/xforms/datatypes.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/xforms/datatypes.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/xforms/datatypes.hxx (original)
+++ openoffice/trunk/main/forms/source/xforms/datatypes.hxx Tue Apr 29 19:05:05 2014
@@ -219,11 +219,11 @@ namespace xforms
 
             The normalization must respect the "<" and "==" relations on the value
             space. That is, if two values are equal, their normalizations must be equal, too.
-            Similarily, if <code>foo</code> is less than <code>bar</code>, the same
+            Similarly, if <code>foo</code> is less than <code>bar</code>, the same
             must hold for their normalizations.
 
             @param _rValue
-                the value to translate. Guranteed to be not <NULL/>, and of type <member>ValueType</member>
+                the value to translate. Guaranteed to be not <NULL/>, and of type <member>ValueType</member>
             @param _rDoubleValue
                 output parameter to hold the resulting double value
         */

Modified: openoffice/trunk/main/forms/source/xforms/model.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/xforms/model.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/xforms/model.cxx (original)
+++ openoffice/trunk/main/forms/source/xforms/model.cxx Tue Apr 29 19:05:05 2014
@@ -289,7 +289,7 @@ void Model::dbg_assertInvariant() const
 
 
 //
-// MIP managment
+// MIP management
 //
 
 void Model::addMIP( void* pTag, const XNode_t& xNode, const MIP& rMIP )

Modified: openoffice/trunk/main/forms/source/xforms/model_ui.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/xforms/model_ui.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/xforms/model_ui.cxx (original)
+++ openoffice/trunk/main/forms/source/xforms/model_ui.cxx Tue Apr 29 19:05:05 2014
@@ -134,7 +134,7 @@ void lcl_OutPosition( OUStringBuffer& rB
 {
     OSL_ENSURE( xNode->getParentNode().is(), "need parent" );
 
-    // count # of occurences of this node
+    // count # of occurrences of this node
     sal_Int32 nFound = 0;
     sal_Int32 nPosition = -1;
     if( xNode->getParentNode().is() )

Modified: openoffice/trunk/main/formula/source/core/api/token.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/formula/source/core/api/token.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/formula/source/core/api/token.cxx (original)
+++ openoffice/trunk/main/formula/source/core/api/token.cxx Tue Apr 29 19:05:05 2014
@@ -1051,7 +1051,7 @@ bool FormulaMissingContext::AddMissing( 
 
             case ocOffset:
                 // FIXME: rather tough.
-                // if arg 3 (height) ommitted, export arg1 (rows)
+                // if arg 3 (height) omitted, export arg1 (rows)
                 break;
             default:
                 break;

Modified: openoffice/trunk/main/fpicker/source/aqua/SalAquaFilePicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/aqua/SalAquaFilePicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/aqua/SalAquaFilePicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/aqua/SalAquaFilePicker.cxx Tue Apr 29 19:05:05 2014
@@ -86,7 +86,7 @@ using namespace ::com::sun::star::uno;
 
 namespace
 {
-    // controling event notifications
+    // controlling event notifications
     const bool STARTUP_SUSPENDED = true;
     const bool STARTUP_ALIVE     = false;
 

Modified: openoffice/trunk/main/fpicker/source/aqua/SalAquaFolderPicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/aqua/SalAquaFolderPicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/aqua/SalAquaFolderPicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/aqua/SalAquaFolderPicker.cxx Tue Apr 29 19:05:05 2014
@@ -73,7 +73,7 @@ using namespace ::com::sun::star::uno;
 
 namespace
 {
-    // controling event notifications
+    // controlling event notifications
     uno::Sequence<rtl::OUString> SAL_CALL FolderPicker_getSupportedServiceNames()
     {
         uno::Sequence<rtl::OUString> aRet(2);

Modified: openoffice/trunk/main/fpicker/source/office/OfficeFilePicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/office/OfficeFilePicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/office/OfficeFilePicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/office/OfficeFilePicker.cxx Tue Apr 29 19:05:05 2014
@@ -267,7 +267,7 @@ WinBits SvtFilePicker::getWinBits( WinBi
 	WinBits nBits = 0L;
     rExtraBits = 0L;
 
-	// set the standard bits acording to the service name
+	// set the standard bits according to the service name
     if ( m_nServiceType == TemplateDescription::FILEOPEN_SIMPLE )
 	{
 		nBits = WB_OPEN;

Modified: openoffice/trunk/main/fpicker/source/office/fpinteraction.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/office/fpinteraction.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/office/fpinteraction.cxx (original)
+++ openoffice/trunk/main/fpicker/source/office/fpinteraction.cxx Tue Apr 29 19:05:05 2014
@@ -93,7 +93,7 @@ namespace svt
 
         // intercept some interesting interactions
 
-        // The "does not exist" interaction will be supressed here completly.
+        // The "does not exist" interaction will be suppressed here completly.
         if (m_eInterceptions & OFilePickerInteractionHandler::E_DOESNOTEXIST)
         {
             InteractiveIOException aIoException;

Modified: openoffice/trunk/main/fpicker/source/office/fpsmartcontent.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/office/fpsmartcontent.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/office/fpsmartcontent.cxx (original)
+++ openoffice/trunk/main/fpicker/source/office/fpsmartcontent.cxx Tue Apr 29 19:05:05 2014
@@ -93,7 +93,7 @@ namespace svt
     void SmartContent::enableDefaultInteractionHandler()
     {
         // Don't free the memory here! It will be done by the next
-        // call automaticly - releasing of the uno reference ...
+        // call automatically - releasing of the uno reference ...
         m_pOwnInteraction = NULL;
         m_xOwnInteraction = Reference< XInteractionHandler >();
 
@@ -127,7 +127,7 @@ namespace svt
     void SmartContent::disableInteractionHandler()
     {
         // Don't free the memory here! It will be done by the next
-        // call automaticly - releasing of the uno reference ...
+        // call automatically - releasing of the uno reference ...
         m_pOwnInteraction = NULL;
         m_xOwnInteraction.clear();
 
@@ -201,12 +201,12 @@ namespace svt
             else
                 bIs = m_pContent->isDocument();
 
-            // from here on, we definately know that the content is valid
+            // from here on, we definitely know that the content is valid
             m_eState = VALID;
         }
         catch( Exception& )
         {
-            // now we're definately invalid
+            // now we're definitely invalid
             m_eState = INVALID;
         }
         return bIs;
@@ -224,12 +224,12 @@ namespace svt
             m_pContent->getPropertyValue( ::rtl::OUString::createFromAscii( "Title" ) ) >>= sTitle;
             _rTitle =  sTitle;
 
-            // from here on, we definately know that the content is valid
+            // from here on, we definitely know that the content is valid
             m_eState = VALID;
         }
         catch( ::com::sun::star::uno::Exception& )
         {
-            // now we're definately invalid
+            // now we're definitely invalid
             m_eState = INVALID;
         }
     }
@@ -252,14 +252,14 @@ namespace svt
                     String aParentURL = String( xParent->getIdentifier()->getContentIdentifier() );
                     bRet = ( aParentURL.Len() > 0 && aParentURL != (String)(m_pContent->getURL()) );
 
-                    // now we're definately valid
+                    // now we're definitely valid
                     m_eState = VALID;
                 }
             }
         }
         catch( const Exception& )
         {
-            // now we're definately invalid
+            // now we're definitely invalid
             m_eState = INVALID;
         }
         return bRet;
@@ -287,12 +287,12 @@ namespace svt
                 }
             }
 
-            // now we're definately valid
+            // now we're definitely valid
             m_eState = VALID;
         }
         catch( Exception& )
         {
-            // now we're definately invalid
+            // now we're definitely invalid
             m_eState = INVALID;
         }
         return bRet;

Modified: openoffice/trunk/main/fpicker/source/office/iodlg.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/office/iodlg.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/office/iodlg.cxx (original)
+++ openoffice/trunk/main/fpicker/source/office/iodlg.cxx Tue Apr 29 19:05:05 2014
@@ -2253,7 +2253,7 @@ short SvtFileDialog::PrepareExecute()
 
 	UpdateControls( aObj.GetMainURL( INetURLObject::NO_DECODE ) );
 
-    // Somebody might want to enable some controls acording to the current filter
+    // Somebody might want to enable some controls according to the current filter
     FilterSelect();
 
 	// Zustand der Steuerelemente anpassen.
@@ -3137,7 +3137,7 @@ void SvtFileDialog::setImage( sal_Int16 
 sal_Bool SvtFileDialog::setShowState( sal_Bool /*bShowState*/ )
 {
 	// #97633 for the system filedialog it's
-	// usefull to make the preview switchable
+	// useful to make the preview switchable
 	// because the preview occupies
 	// half of the size of the file listbox
 	// which is not the case here,

Modified: openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFilePicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFilePicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFilePicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFilePicker.cxx Tue Apr 29 19:05:05 2014
@@ -73,7 +73,7 @@ using namespace ::com::sun::star::uno;
 
 namespace
 {
-	// controling event notifications    
+	// controlling event notifications    
 	const bool STARTUP_SUSPENDED = true;
 	const bool STARTUP_ALIVE     = false;
     

Modified: openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFolderPicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFolderPicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFolderPicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/unx/gnome/SalGtkFolderPicker.cxx Tue Apr 29 19:05:05 2014
@@ -66,7 +66,7 @@ using namespace ::com::sun::star::uno;
 
 namespace
 {
-	// controling event notifications
+	// controlling event notifications
 	uno::Sequence<rtl::OUString> SAL_CALL FolderPicker_getSupportedServiceNames()
 	{
         uno::Sequence<rtl::OUString> aRet(2);

Modified: openoffice/trunk/main/fpicker/source/unx/kde4/KDE4FilePicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/unx/kde4/KDE4FilePicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/unx/kde4/KDE4FilePicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/unx/kde4/KDE4FilePicker.cxx Tue Apr 29 19:05:05 2014
@@ -86,7 +86,7 @@ using namespace ::com::sun::star::uno;
 
 namespace
 {
-    // controling event notifications    
+    // controlling event notifications    
     const bool STARTUP_SUSPENDED = true;
     const bool STARTUP_ALIVE     = false;
 

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/FileOpenDlg.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/FileOpenDlg.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/FileOpenDlg.hxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/FileOpenDlg.hxx Tue Apr 29 19:05:05 2014
@@ -209,10 +209,10 @@ public:
 	// the method returns:
 	//  0 - when the dialog was canceled by the user
 	//  1 - when the dialog was closed with ok
-	// -1 - when an error occured
+	// -1 - when an error occurred
 	sal_Int16 SAL_CALL doModal();
 
-	// returns the last dialog error that occured
+	// returns the last dialog error that occurred
 	sal_uInt32 SAL_CALL getLastDialogError() const;
 	
 	// retrievs the currently selected file

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/FilePicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/FilePicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/FilePicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/FilePicker.cxx Tue Apr 29 19:05:05 2014
@@ -66,7 +66,7 @@ using namespace ::com::sun::star::ui::di
 
 namespace
 {
-    // controling event notifications    
+    // controlling event notifications    
     const bool STARTUP_SUSPENDED = true;
     const bool STARTUP_ALIVE     = false;
     

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.cxx Tue Apr 29 19:05:05 2014
@@ -259,7 +259,7 @@ CFilePreview::CFilePreview( 
 	wndClsEx.lpszClassName = PREVIEWWND_CLASS_NAME;
 		
 	// register the preview window class
-	// !!! Win95 -   the window class will be unregistered automaticly 
+	// !!! Win95 -   the window class will be unregistered automatically 
 	//			     if the dll is unloaded
 	//     Win2000 - the window class must be unregistered manually
 	//				 if the dll is unloaded
@@ -414,7 +414,7 @@ sal_Bool SAL_CALL CFilePreview::show( sa
 // if the preview is shown and enabled 
 // preview of the given file will be shown
 // returns true on success or false if an error
-// occured (the file in not there or not accessible etc.)
+// occurred (the file in not there or not accessible etc.)
 //---------------------------------------------------
 
 sal_Bool SAL_CALL CFilePreview::update( const rtl::OUString& aFileName )

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.hxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/PreviewCtrl.hxx Tue Apr 29 19:05:05 2014
@@ -147,7 +147,7 @@ public:
 	// if the preview is shown and enabled 
 	// preview of the given file will be shown
 	// returns true on success or false if an error
-	// occured (the file in not there or not accessible etc.)
+	// occurred (the file in not there or not accessible etc.)
 	virtual sal_Bool SAL_CALL update( const rtl::OUString& aFileName );
 
 protected:	

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePicker.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePicker.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePicker.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePicker.cxx Tue Apr 29 19:05:05 2014
@@ -80,7 +80,7 @@ namespace vista{
 
 namespace
 {
-    // controling event notifications    
+    // controlling event notifications    
     const bool STARTUP_SUSPENDED = true;
     const bool STARTUP_ALIVE     = false;
     
@@ -321,7 +321,7 @@ void SAL_CALL VistaFilePicker::setDispla
 }
 
 //-----------------------------------------------------------------------------------------
-// @deprecated cant be supported any longer ... see IDL description for further details
+// @deprecated can't be supported any longer ... see IDL description for further details
 css::uno::Sequence< ::rtl::OUString > SAL_CALL VistaFilePicker::getFiles()
     throw(css::uno::RuntimeException)
 {

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.cxx Tue Apr 29 19:05:05 2014
@@ -876,7 +876,7 @@ void VistaFilePickerImpl::impl_sta_ShowD
     TFileSaveDialog iSave = m_iDialogSave;
 
 	// it's important to know if we are showing the dialog.
-    // Some dialog interface methods cant be called then or some
+    // Some dialog interface methods can't be called then or some
     // tasks must be done differently .-) (e.g. see impl_sta_getSelectedFiles())
     m_bInExecute = sal_True;
 

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/VistaFilePickerImpl.hxx Tue Apr 29 19:05:05 2014
@@ -260,9 +260,9 @@ class VistaFilePickerImpl : private ::cp
         void impl_sta_EnableControl(const RequestRef& rRequest);
     
         //---------------------------------------------------------------------
-        /** create all needed (optional!) UI controls adressed by the field nFeatures.
+        /** create all needed (optional!) UI controls addressed by the field nFeatures.
          *  The given number nFeatures is used as a flag field. Use const values FEATURE_XXX
-         *  to adress it.
+         *  to address it.
          *
          *  Internal new controls will be added to the dialog. Every control can be accessed
          *  by it's own control id. Those control ID must be one of the const set

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/WinFileOpenImpl.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/WinFileOpenImpl.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/WinFileOpenImpl.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/WinFileOpenImpl.cxx Tue Apr 29 19:05:05 2014
@@ -683,7 +683,7 @@ void SAL_CALL CWinFileOpenImpl::onSelCha
     // string to the file name edit line
     // this would overwritte our text when we would set
     // the default name in onInitDone, so we have to 
-    // remeber that this is the first SelChanged message
+    // remember that this is the first SelChanged message
     // and set the default name here to overwrite the
     // windows setting
     InitialSetDefaultName();

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/dialogcustomcontrols.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/dialogcustomcontrols.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/dialogcustomcontrols.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/dialogcustomcontrols.cxx Tue Apr 29 19:05:05 2014
@@ -70,7 +70,7 @@ void SAL_CALL CDialogCustomControlBase::
 	int cy_new = rcBuddy.bottom - rcBuddy.top;
 
 	// keep the vertical position because
-	// the Windows dialog controler does
+	// the Windows dialog controller does
 	// this job
 	RECT rcMe;
 	GetWindowRect(m_CustomControlHandle,&rcMe);

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/dibpreview.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/dibpreview.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/dibpreview.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/dibpreview.cxx Tue Apr 29 19:05:05 2014
@@ -419,7 +419,7 @@ ATOM SAL_CALL CDIBPreview::RegisterDibPr
 	    wndClsEx.lpszClassName = PREVIEWWND_CLASS_NAME;
 
 	    // register the preview window class
-	    // !!! Win95 -   the window class will be unregistered automaticly
+	    // !!! Win95 -   the window class will be unregistered automatically
 	    //			     if the dll is unloaded
 	    //     Win2000 - the window class must be unregistered manually
 	    //				 if the dll is unloaded

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/filepickerstate.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/filepickerstate.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/filepickerstate.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/filepickerstate.cxx Tue Apr 29 19:05:05 2014
@@ -665,7 +665,7 @@ inline sal_Bool SAL_CALL CExecuteFilePic
 
 //---------------------------------------------
 // because listboxes (comboboxes) and their labels
-// are seperated we have to translate the listbox
+// are separated we have to translate the listbox
 // id to their corresponding label id
 // the convention is that the label id of a listbox
 // is the id of the listbox + 100

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.cxx Tue Apr 29 19:05:05 2014
@@ -561,7 +561,7 @@ ATOM SAL_CALL CHelpPopupWindow::Register
 	    wndClsEx.lpszClassName = HELPPOPUPWND_CLASS_NAME;
 		        
 	    // register the preview window class
-	    // !!! Win95 -   the window class will be unregistered automaticly 
+	    // !!! Win95 -   the window class will be unregistered automatically 
 	    //			     if the dll is unloaded
 	    //     Win2000 - the window class must be unregistered manually
 	    //				 if the dll is unloaded

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.hxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/helppopupwindow.hxx Tue Apr 29 19:05:05 2014
@@ -86,9 +86,9 @@ public:
 
     /*
         Shows the window with the text that was last set.
-        The posistion is the prefered position. The window
+        The position is the preferred position. The window
         may itself show at a slightly different position
-        if it fits not at the prefered position.
+        if it fits not at the preferred position.
     */
     void SAL_CALL show( sal_Int32 x, sal_Int32 y );
 

Modified: openoffice/trunk/main/fpicker/source/win32/filepicker/workbench/Test_fps.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/filepicker/workbench/Test_fps.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/filepicker/workbench/Test_fps.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/filepicker/workbench/Test_fps.cxx Tue Apr 29 19:05:05 2014
@@ -267,7 +267,7 @@ int SAL_CALL main(int nArgc, char* Argv[
 	OUString rdbName = OUString( RTL_CONSTASCII_USTRINGPARAM( RDB_SYSPATH ) );
 	Reference< XMultiServiceFactory > g_xFactory( createRegistryServiceFactory( rdbName ) );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( g_xFactory.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Can't create RegistryServiceFactory");
@@ -366,7 +366,7 @@ int SAL_CALL main(int nArgc, char* Argv[
 	// Cast factory to XComponent
 	Reference< XComponent > xComponent( g_xFactory, UNO_QUERY );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( xComponent.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Error shuting down");

Modified: openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.cxx Tue Apr 29 19:05:05 2014
@@ -197,7 +197,7 @@ CMtaFolderPicker::~CMtaFolderPicker( )
                 
         // force the destruction of the sta thread request window
         // and the end of the thread
-        // remeber: DestroyWindow may only be called from within
+        // remember: DestroyWindow may only be called from within
         // the thread that created the window
         if ( IsWindow( m_hwndStaRequestWnd ) )
         {
@@ -205,7 +205,7 @@ CMtaFolderPicker::~CMtaFolderPicker( )
 
             // we place unregister class here because 
             // if we have a valid window we must have 
-            // sucessfully registered a window class
+            // successfully registered a window class
             // if the creation of the window itself 
             // failed after registering the window 
             // class we have unregistered it immediately

Modified: openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.hxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/folderpicker/MtaFop.hxx Tue Apr 29 19:05:05 2014
@@ -140,7 +140,7 @@ private:
 	sal_Bool SAL_CALL createStaRequestWindow( );
 
 	//---------------------------------------------------------------
-	// message handler functions; remeber these functions are called
+	// message handler functions; remember these functions are called
 	// from a different thread context!
 	//---------------------------------------------------------------
 

Modified: openoffice/trunk/main/fpicker/source/win32/folderpicker/workbench/Test_fops.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/fpicker/source/win32/folderpicker/workbench/Test_fops.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/fpicker/source/win32/folderpicker/workbench/Test_fops.cxx (original)
+++ openoffice/trunk/main/fpicker/source/win32/folderpicker/workbench/Test_fops.cxx Tue Apr 29 19:05:05 2014
@@ -129,7 +129,7 @@ int SAL_CALL main(int /*nArgc*/, char* /
 	OUString rdbName = OUString( RTL_CONSTASCII_USTRINGPARAM( RDB_SYSPATH ) );
 	Reference< XMultiServiceFactory > g_xFactory( createRegistryServiceFactory( rdbName ) );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( g_xFactory.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Can't create RegistryServiceFactory");
@@ -180,7 +180,7 @@ int SAL_CALL main(int /*nArgc*/, char* /
 	// Cast factory to XComponent
 	Reference< XComponent > xComponent( g_xFactory, UNO_QUERY );
 
-	// Print a message if an error occured.
+	// Print a message if an error occurred.
 	if ( xComponent.is() == sal_False )
 	{
 		OSL_ENSURE(sal_False, "Error shuting down");

Modified: openoffice/trunk/main/framework/inc/classes/checkediterator.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/classes/checkediterator.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/classes/checkediterator.hxx (original)
+++ openoffice/trunk/main/framework/inc/classes/checkediterator.hxx Tue Apr 29 19:05:05 2014
@@ -61,7 +61,7 @@ namespace framework{
 	@short          implement a iterator which support 2 end states!
 	@descr			For our search methods we need a "walking" iterator object with special functionality!
 					We must check for 3 different states of an iterator - normal position, exact end, after end.
-					It's neccessary to detect if we have not found a entry and must return our default or
+					It's necessary to detect if we have not found a entry and must return our default or
 					default already returned and we must break loop!
 					see using in class FilterCache too for further informations!
 
@@ -114,7 +114,7 @@ class CheckedIterator
 
 		/*-****************************************************************************************************//**
 			@short		initialize instance with valid container
-			@descr		Set new container at an instance of this class. The other member will set automaticly!
+			@descr		Set new container at an instance of this class. The other member will set automatically!
 						m_pPosition = first element in container
 						m_eEndState = BEFOREEND
 

Modified: openoffice/trunk/main/framework/inc/classes/droptargetlistener.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/classes/droptargetlistener.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/classes/droptargetlistener.hxx (original)
+++ openoffice/trunk/main/framework/inc/classes/droptargetlistener.hxx Tue Apr 29 19:05:05 2014
@@ -59,7 +59,7 @@ class DropTargetListener : private Threa
     // member
 	private:
 
-        /// uno service manager to create neccessary services
+        /// uno service manager to create necessary services
         css::uno::Reference< css::lang::XMultiServiceFactory > m_xFactory;
         /// weakreference to target frame (Don't use a hard reference. Owner can't delete us then!)
         css::uno::WeakReference< css::frame::XFrame > m_xTargetFrame;

Modified: openoffice/trunk/main/framework/inc/classes/filtercache.hxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/framework/inc/classes/filtercache.hxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/framework/inc/classes/filtercache.hxx (original)
+++ openoffice/trunk/main/framework/inc/classes/filtercache.hxx Tue Apr 29 19:05:05 2014
@@ -83,7 +83,7 @@ namespace framework{
 /*-************************************************************************************************************//**
 	@short          cache for all filter and type information
 	@descr			Frameloader- and filterfactory need some informations about our current registered filters and types.
-					For better performance its neccessary to cache all needed values.
+					For better performance its necessary to cache all needed values.
 
 	@implements		-
     @base           ThreadHelpBase
--- openoffice/trunk/main/filter/source/msfilter/msocximex.cxx (original)
+++ openoffice/trunk/main/filter/source/msfilter/msocximex.cxx Tue Apr 29 19:05:05 2014
@@ -113,7 +113,7 @@ long ReadAlign(SvStorageStream *pS, long
 // referenced externally. On import from ms document try to save images for controls here.
 // Images are stored in directory called temp in the user installation directory. Next version of OO/SO
 // hopefully will address this issue and allow a choice e.g. images for controls to be stored as links
-// or embeded in the document.
+// or embedded in the document.
 
 // [out]location     path to the stream to where the image is to be stored,
 //               if same name exists in folder then this function calcuates a new name
@@ -740,7 +740,7 @@ class ContainerRecReader
     {
         sal_uInt32 nUnknown_32b; // unknown 32 bit structure, flags ?
         sal_uInt16 nUnknown_16b; // unknown 16 bit structure
-        sal_uInt16 nMysteryLen; // lenght of unknown sub record
+        sal_uInt16 nMysteryLen; // length of unknown sub record
 
         *pS >> nUnknown_32b;
         *pS >> nUnknown_16b;
@@ -4487,7 +4487,7 @@ OCX_Control * SvxMSConvertOCXControls::O
 //Begin nasty hack
 	/*
 	There is a truly horrible thing with EditControls and FormattedField
-	Controls, they both pretend to have an EDITBOX ClassId for compability
+	Controls, they both pretend to have an EDITBOX ClassId for compatibility
 	reasons, at some stage in the future hopefully there will be a proper
 	FormulaField ClassId rather than this piggybacking two controls onto the
 	same ClassId, when this happens uncomment the FORMULAFIELD in the OCX_Tab
@@ -4566,8 +4566,8 @@ sal_Bool SvxMSConvertOCXControls::ReadOC
 	pSt->SetNumberFormatInt( NUMBERFORMAT_INT_LITTLEENDIAN );
 
 	/*Get Class Id of this object, see if it is one of the types
-	 *that this importer can handle, call the appropiate handler
-	 to read that control, and call the appropiate handler to
+	 *that this importer can handle, call the appropriate handler
+	 to read that control, and call the appropriate handler to
 	 insert that control
 	 */
 
@@ -4603,8 +4603,8 @@ sal_Bool SvxMSConvertOCXControls::ReadOC
 {
 	sal_Bool bRet=sal_False;
 	/*Get Class Id of this object, see if it is one of the types
-	 *that this importer can handle, call the appropiate handler
-	 to read that control, and call the appropiate handler to
+	 *that this importer can handle, call the appropriate handler
+	 to read that control, and call the appropriate handler to
 	 insert that control
 	 */
 	/*The Excel Kludge is to concatenate a class id with a contents

Modified: openoffice/trunk/main/filter/source/msfilter/msvbahelper.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/filter/source/msfilter/msvbahelper.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================
--- openoffice/trunk/main/forms/source/richtext/richtextimplcontrol.cxx (original)
+++ openoffice/trunk/main/forms/source/richtext/richtextimplcontrol.cxx Tue Apr 29 19:05:05 2014
@@ -67,7 +67,7 @@ namespace frm
         ,m_bHasEverBeenShown    ( false               )
     {
         OSL_ENSURE( m_pAntiImpl, "RichTextControlImpl::RichTextControlImpl: invalid window!" );
-        OSL_ENSURE( m_pEngine,   "RichTextControlImpl::RichTextControlImpl: invalid edit engine! This will *definately* crash!" );
+        OSL_ENSURE( m_pEngine,   "RichTextControlImpl::RichTextControlImpl: invalid edit engine! This will *definitely* crash!" );
 
         m_pViewport = new RichTextViewPort( m_pAntiImpl );
         m_pViewport->setAttributeInvalidationHandler( LINK( this, RichTextControlImpl, OnInvalidateAllAttributes ) );
@@ -124,7 +124,7 @@ namespace frm
             // type (Latin, Asian, Complex). However, if we have an observer who is interested
             // in the state of this attribute, we have to kind of *merge* the three attributes
             // to only one.
-            // This is usefull in case the observer is for instance a toolbox which contains only
+            // This is useful in case the observer is for instance a toolbox which contains only
             // an, e.g., "bold" slot, and thus not interested in the particular script type of the
             // current selection.
             SvxScriptSetItem aNormalizedSet( (WhichId)_pHandler->first, *m_pView->GetAttribs().GetPool() );
@@ -307,7 +307,7 @@ namespace frm
         // the AutoPaperSize bits set.
         // So in order to be properly notified, we would need the AutoPaperSize. But, with
         // AutoPaperSize, other things do not work anymore: Either, when we set a MaxAutoPaperSize,
         // then the view does automatic soft line breaks at the paper end - which we definately do
         // want. Or, if we did not set a MaxAutoPaperSize, then the view does not automatically scroll
         // anymore in horizontal direction.
         // So this is some kind of lose-lose situation ... :(
@@ -307,7 +307,7 @@ namespace frm
         // So in order to be properly notified, we would need the AutoPaperSize. But, with
         // AutoPaperSize, other things do not work anymore: Either, when we set a MaxAutoPaperSize,
-        // then the view does automatic soft line breaks at the paper end - which we definately do
+        // then the view does automatic soft line breaks at the paper end - which we definitely do
         // want. Or, if we did not set a MaxAutoPaperSize, then the view does not automatically scroll
         // anymore in horizontal direction.

Modified: openoffice/trunk/main/forms/source/solar/component/navbarcontrol.cxx
URL: http://svn.apache.org/viewvc/openoffice/trunk/main/forms/source/solar/component/navbarcontrol.cxx?rev=1591058&r1=1591057&r2=1591058&view=diff
==============================================================================